@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Bakerloo;
 
-$Map::Tube::London::Line::Bakerloo::VERSION = '0.26';
+$Map::Tube::London::Line::Bakerloo::VERSION = '0.27';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Map::Tube::London::Line::Bakerloo - London Tube Map Bakerloo Line stations.
 
 =head1 VERSION
 
-Version 0.26
+Version 0.27
 
 =head1 DESCRIPTION
 
@@ -59,7 +59,8 @@ London Tube Map Bakerloo Line stations.
 
 =item * The station "Baker Street" is also part of L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
-        | Jubilee Line | Metropolitan Line.
+        | L<Jubilee Line|Map::Tube::London::Line::Jubilee>
+        | Metropolitan Line.
 
 =back
 
